Overview
========

Extensions for logbook, such as Windows EventLog handler.

Checking out the code
=====================

Run the following:

    easy_install -U infi.projector
    projector devenv build
